/*
   (c) 2021 Christian Grieger
   GNU GENERAL PUBLIC LICENSE
*/

#include <HouseLighting.h>

const byte HouseLighting::OFF = 0;
const byte HouseLighting::ON  = 1;

HouseLighting::HouseLighting (byte ledPin, int timeOn, int timeOff, byte initialState)
{
  pin = ledPin;

  delays[OFF] = timeOff;
  delays[ON] = timeOn;

  pinMode(pin, OUTPUT);
  
  if (initialState == ON) {
    currentState = ON;
    digitalWrite(pin, HIGH);
  } else {
    currentState = OFF;
    digitalWrite(pin, LOW);
  }

  nextAction = (long)millis() + delays[currentState] * 1000;
}

void HouseLighting::update()
{
  if ((long)millis() - nextAction >= 0) {
    if (currentState == ON) {
      currentState = OFF;
    } else {
      currentState = ON;
    }

    digitalWrite(pin, currentState);
    nextAction = (long)millis() + delays[currentState] * 1000;
  }
}
